%% Code for the Undersampled MRI reconstruction with patch-based directional wavelets
%% The L1 norm minimization problem is solved via an alternating direction method with continuation
%% Xiaobo Qu
%% Xiamen University
%% Email: quxiaobo <at> xmu.edu.cn
%% June 03, 2012
%% If you use this code, please cite our papers:
%% [1] Xiaobo Qu, Di Guo, Bende Ning, Yingkun Hou, Yulan Lin, Shuhui Cai, Zhong Chen. Undersampled MRI reconstruction with patch-based directional wavelets, Magnetic Resonance Imaging, doi:10.1016/j.mri.2012.02.019, 2012.
%%
clc;
clear all;
close all;
clear classes;
%%
Path_PBDW
%% generate the fully sampled data
% im_ori=csphantom (256);
%% generate the undersampled data
% sampling_rate=0.30;
% kspace_full=fft2c(im_ori);
% imwrite(abs(im_ori),'im_ori.tif');
% load mask_series_cartesian
% if sampling_rate==0.30
%     mask=mask_series_cartesian(:,:,6);
% end
%% Data for the Figure 6
load data_NonSparsePhantom_030
%%
[row,column]=size(kspace_full);
imwrite(abs(im_ori),'im_ori.tif');
imwrite(mask,'mask.tif');
y=mask_downsample(mask,row,column)*kspace_full;
%% SIDWT-based CS-MRI
filterType='Daubechies';
filterSize=4;
wavScale=4;
complex_Yes=1;
paramsSIDWT.psi=SIDWT(filterType,filterSize,wavScale,complex_Yes); % define the shift-invariant wavelets operator
paramsSIDWT.lamda=1e6;
tic
im_rec_SIDWT=solver_ADMC(y,mask,paramsSIDWT); % solve the L1 norm minimization problem with ADMC
time_SIDWT_CS=toc;
Eval_SIDWT=RLNE(im_ori,im_rec_SIDWT)
figure,imshow(abs([im_rec_SIDWT im_ori]),[0 1])
imwrite(abs(im_rec_SIDWT),'im_rec_SIDWT.tif');
%% PBDW-based CS-MRI
paramsPBDW.lamda=1e6;
paramsPBDW.iter_optDirections=2;% Times to train the geometric directions
paramsPBDW.ref_init=im_rec_SIDWT;% Guide image is here. Use 'im_ori' as the guide image with fully sampled data;
% paramsPBDW.ref_init=im_ori;%Use 'im_ori' as the guide image with fully sampled data;
paramsPBDW.ShowGeo=1;% Show the geometric directions? Yes:1, No:0

paramsGeo.overlapFactor=16;
paramsGeo.patchSize=8;

tic
im_rec_PBDW=solver_PBDW_CSMRI(y,mask,paramsPBDW,paramsGeo);
time_PBDW_CS=toc
Eval_PBDW=RLNE(im_ori,im_rec_PBDW)
imwrite(abs(im_rec_PBDW),'im_rec_PBDW.tif');
%%