%% Test the forward and inverse patch-based directional wavelets
%% Xiaobo Qu, Bende Ning
%% Department of Electronic Science, Xiamen University
%% quxiaobo <at> xmu.edu.cn
%% June 03, 2012
%% If you use this code, please cite the following papers:
%% [1]Xiaobo Qu, Di Guo, Bende Ning, Yingkun Hou, Yulan Lin, Shuhui Cai, Zhong Chen. Undersampled MRI reconstruction with patch-based directional wavelets, Magnetic Resonance Imaging, doi:10.1016/j.mri.2012.02.019, 2012.
%% [2]Peyr G, Mallat S. Surface compression with geometric bandelets. Acm Trans Graphic 2005; 24:601-608.
clc;
clear all;
close all;
clear classes;
%%
paramsGeo.patchSize=8;
paramsGeo.S=(paramsGeo.patchSize).^2/4;
paramsGeo.Scales=3;
paramsGeo.overlapFactor=16;
%%
im_ori=phantom(256)+1i*phantom(256)';
im_ref=real(im_ori);
%%
paramsGeo.row=size(im_ori,1);
paramsGeo.column=size(im_ori,2);
%%
[paramsGeo.Lut,paramsGeo.Theta]= compute_geometric_lut_limitedAngle(paramsGeo.patchSize);
%%
[patches,paramsGeo.struct]=im2patch(im_ori,1,paramsGeo);
%%
tic
[patches_ref,paramsGeo.struct]=im2patch(im_ref,1,paramsGeo);
Geo=Est_Geo(abs(patches_ref),paramsGeo.Lut,paramsGeo.S,paramsGeo.Scales);
Time_EstGeo=toc
%% Forward PBDW
tic
WtCoeffs=PBDW_Forward_Complex(patches,Geo,paramsGeo.Lut,paramsGeo.Scales);
PBDW_Forward_time=toc
%% Inverse PBDW
tic
patches_rec=PBDW_Backward_Complex(WtCoeffs,Geo,paramsGeo.Lut,paramsGeo.Scales);
PBDW_Backward_time=toc
im_rec=im2patch(patches_rec,-1,paramsGeo)/paramsGeo.overlapFactor;
%%
figure,plot_geometry_simple(reshape(Geo(:,1:(paramsGeo.row/paramsGeo.patchSize)*(paramsGeo.column/paramsGeo.patchSize)),paramsGeo.row/paramsGeo.patchSize,paramsGeo.column/paramsGeo.patchSize),im_ref, paramsGeo);
figure,imshow([real(im_rec-im_ori) imag(im_rec-im_ori)],[]),colorbar
%% Simple usage of @operator
PBDW=PBDW_OP(Geo,paramsGeo);
WtCoeffs=PBDW*im_ori;
im_rec=(PBDW'*WtCoeffs)./paramsGeo.overlapFactor;
figure,imshow([real(im_rec-im_ori) imag(im_rec-im_ori)],[]),colorbar