function plot_geometry_simple(G, M, params)

% plot_quadtree - graphical display of a quatree
%
%   plot_geometry(G, M, params);
%
%   G is a matrix containing the chosen geometry inside each square.
%   M is an arbitrary background image
%
%   Copyright (c) 2005 Gabriel Peyr?
%   Revised by Xiaobo Qu, July 26, 2011
if nargin<2
    M = [];
end
if iscell(G)
    G = G{1};
end
if nargin<3
    nT = ceil(size(G,3)/2);
end

% width of the squares
n = size(M);
params.null = 0;
if isfield(params, 'patchSize')
    patchSize = params.patchSize;
else
    patchSize=8;
end

if size(patchSize,2)==1
    patchSize = [patchSize patchSize];
end

nw = size(G);

str = 'r';
str_add = 'b';

hold on;
% display image with an overlaid grid
imagesc([1/2,n(1)-1/2], [1/2,n(2)-1/2], M);
if (~isfield(params, 'Lut'))||(~isfield(params, 'Theta'))
    [Lut,Theta]= compute_geometric_lut_limitedAngle(patchSize,1);
else
    Lut= params.Lut;
    Theta=params.Theta;
end

lw = 0.1;% Xiaobo Revised, original lw = 2;
lw_square=0.25;% Xiaobo Revised
% display subdivision
for kx=1:nw(1)
    for ky=1:nw(2)
        % center of the square
        pos = [kx-1,ky-1].*patchSize + patchSize/2;
        if G(kx,ky)==0
            % no geometry
        elseif G(kx,ky)<=length(Theta)
            % plot a geometry
            theta = Theta(G(kx,ky));
            r = min(patchSize)/2;
            x = pos(1) + [cos(theta), -cos(theta)]*r;
            y = pos(2) + [sin(theta), -sin(theta)]*r;
            h = plot(y,x, str);
%             h1 = plot(y,x, str);
            set(h, 'LineWidth', lw);
%             set(h1, 'LineWidth', lw_square);
        end
    end
end

hold on

lw_direction=2;
% draw the lines
nmax = size(G).*patchSize;
for kx = 0:patchSize(1):n(1)
    x = [kx kx]; y = [0 nmax(2)];
    h = plot(y,x, 'k');
%     h2 = plot(y,x, 'k');
    set(h, 'LineWidth', lw);
%     set(h2, 'LineWidth', lw_direction);
end
for kx = 0:patchSize(2):n(2)
    x = [kx kx]; y = [0 nmax(1)];
    h = plot(x,y, 'k');
%     h2 = plot(x,y, 'k');
    set(h, 'LineWidth', lw);
%     set(h2, 'LineWidth', lw_direction);
end

hold off;

axis tight;
axis square;
axis ij;
axis off;
colormap gray(256); 